@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-search-dialog.c 6727 2008-12-25 21:02:48Z pborelli $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -218,14 +218,12 @@ insert_text_handler (GtkEditable *editable,
 }
 
 static void
-search_entry_changed (GtkComboBox       *combo,
-		      GeditSearchDialog *dialog)
+search_text_entry_changed (GtkEditable       *editable,
+			   GeditSearchDialog *dialog)
 {
-	GtkWidget *entry;
 	const gchar *search_string;
 
-	entry = gtk_bin_get_child (GTK_BIN (combo));
-	search_string = gtk_entry_get_text (GTK_ENTRY (entry));
+	search_string = gtk_entry_get_text (GTK_ENTRY (editable));
 	g_return_if_fail (search_string != NULL);
 
 	if (*search_string != '\0')
@@ -340,9 +338,12 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 				
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 2); /* 2 * 5 + 2 = 12 */
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+			     2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
+					5);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
+			     6);
 
 	file = gedit_dirs_get_ui_file ("gedit-search-dialog.ui");
 	ret = gedit_utils_get_ui_objects (file,
@@ -363,9 +364,11 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	{
 		gtk_widget_show (error_widget);
 
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dlg)->vbox),
-					     error_widget);
-		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);					     
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+		                    error_widget,
+		                    TRUE, TRUE, 0);
+		gtk_container_set_border_width (GTK_CONTAINER (error_widget),
+						5);
 
 		dlg->priv->ui_error = TRUE;
 
@@ -440,7 +443,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 					   GEDIT_SEARCH_DIALOG_REPLACE_ALL_RESPONSE,
 					   FALSE);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			    content, FALSE, FALSE, 0);
 	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
@@ -453,9 +456,9 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 			  "insert_text",
 			  G_CALLBACK (insert_text_handler),
 			  NULL);
-	g_signal_connect (dlg->priv->search_entry,
+	g_signal_connect (dlg->priv->search_text_entry,
 			  "changed",
-			  G_CALLBACK (search_entry_changed),
+			  G_CALLBACK (search_text_entry_changed),
 			  dlg);
 
 	g_signal_connect (dlg,
@@ -475,9 +478,14 @@ gedit_search_dialog_new (GtkWindow *parent,
 			    NULL);
 
 	if (parent != NULL)
+	{
 		gtk_window_set_transient_for (GTK_WINDOW (dlg),
 					      parent);
-
+	
+		gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg),
+						    TRUE);
+	}
+	
 	return GTK_WIDGET (dlg);
 }
 
