@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-taglist-plugin-parser.c 6929 2009-03-01 17:04:09Z pborelli $
+ * $Id$
  */
 
 /* FIXME: we should rewrite the parser to avoid using DOM */
@@ -45,7 +45,7 @@
 
 /* we screwed up so we still look here for compatibility */
 #define USER_GEDIT_TAGLIST_PLUGIN_LOCATION_LEGACY ".gedit-2/plugins/taglist/"
-#define USER_GEDIT_TAGLIST_PLUGIN_LOCATION ".gnome2/gedit/taglist/"
+#define USER_GEDIT_TAGLIST_PLUGIN_LOCATION "gedit/taglist/"
 
 TagList *taglist = NULL;
 static gint taglist_ref_count = 0;
@@ -588,7 +588,7 @@ parse_taglist_dir (const gchar *dir)
 
 TagList* create_taglist (const gchar *data_dir)
 {
-	const gchar *home;
+	gchar *pdir;
 
 	gedit_debug_message (DEBUG_PLUGINS, "ref_count: %d", taglist_ref_count);
 
@@ -600,27 +600,43 @@ TagList* create_taglist (const gchar *data_dir)
 	}
 
 #ifndef G_OS_WIN32
+	const gchar *home;
+	const gchar *envvar;
+
 	/* load user's taglists */
+
+	/* legacy dir */
 	home = g_get_home_dir ();
 	if (home != NULL)
 	{
-		gchar *pdir;
-
 		pdir = g_build_filename (home,
 					 USER_GEDIT_TAGLIST_PLUGIN_LOCATION_LEGACY,
 					 NULL);
 		parse_taglist_dir (pdir);
 		g_free (pdir);
+	}
 
-		pdir = g_build_filename (home,
+	/* Support old libgnome env var */
+	envvar = g_getenv ("GNOME22_USER_DIR");
+	if (envvar != NULL)
+	{
+		pdir = g_build_filename (envvar,
 					 USER_GEDIT_TAGLIST_PLUGIN_LOCATION,
 					 NULL);
 		parse_taglist_dir (pdir);
 		g_free (pdir);
 	}
-#else
-	gchar *pdir;
-	
+	else if (home != NULL)
+	{
+		pdir = g_build_filename (home,
+					 ".gnome2",
+					 USER_GEDIT_TAGLIST_PLUGIN_LOCATION,
+					 NULL);
+		parse_taglist_dir (pdir);
+		g_free (pdir);
+	}
+
+#else	
 	pdir = g_build_filename (g_get_user_config_dir (),
 				 "gedit",
 				 "taglist",
